@@ -4,26 +4,17 @@ FreedomBox app for Apache server.
 """
 import os
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
 from plinth import cfg
-from plinth.daemon import Daemon
+from plinth.daemon import Daemon, RelatedDaemon
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.letsencrypt.components import LetsEncrypt
+from plinth.package import Packages
 from plinth.utils import format_lazy, is_valid_user_name
 
-version = 8
-
-is_essential = True
-
-managed_services = ['apache2', 'uwsgi']
-
-managed_packages = [
-    'apache2', 'php-fpm', 'ssl-cert', 'uwsgi', 'uwsgi-plugin-python3'
-]
-
 app = None
 
 
@@ -32,15 +23,21 @@ class ApacheApp(app_module.App):
 
     app_id = 'apache'
 
+    _version = 9
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
 
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               is_essential=is_essential,
-                               name=_('Apache HTTP Server'))
+        info = app_module.Info(app_id=self.app_id, version=self._version,
+                               is_essential=True, name=_('Apache HTTP Server'))
         self.add(info)
 
+        packages = Packages('packages-apache', [
+            'apache2', 'php-fpm', 'ssl-cert', 'uwsgi', 'uwsgi-plugin-python3'
+        ])
+        self.add(packages)
+
         web_server_ports = Firewall('firewall-web', _('Web Server'),
                                     ports=['http', 'https'], is_external=True)
         self.add(web_server_ports)
@@ -53,16 +50,19 @@ class ApacheApp(app_module.App):
         self.add(freedombox_ports)
 
         letsencrypt = LetsEncrypt('letsencrypt-apache', domains='*',
-                                  daemons=[managed_services[0]])
+                                  daemons=['apache2'])
         self.add(letsencrypt)
 
-        daemon = Daemon('daemon-apache', managed_services[0])
+        daemon = Daemon('daemon-apache', 'apache2')
+        self.add(daemon)
+
+        daemon = RelatedDaemon('related-daemon-apache', 'uwsgi')
         self.add(daemon)
 
 
 def setup(helper, old_version=None):
     """Configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     actions.superuser_run(
         'apache',
         ['setup', '--old-version', str(old_version)])
