@@ -5,7 +5,7 @@ FreedomBox app for bepasty.
 
 import json
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -13,13 +13,10 @@ from plinth import frontpage, menu
 from plinth.modules.apache.components import Uwsgi, Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
+from plinth.package import Packages
 
 from . import manifest
 
-version = 2
-
-managed_packages = ['bepasty']
-
 _description = [
     _('bepasty is a web application that allows large files to be uploaded '
       'and shared. Text and code snippets can also be pasted and shared. '
@@ -57,11 +54,13 @@ class BepastyApp(app_module.App):
 
     app_id = 'bepasty'
 
+    _version = 2
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
 
-        info = app_module.Info(self.app_id, version, name=_('bepasty'),
+        info = app_module.Info(self.app_id, self._version, name=_('bepasty'),
                                icon_filename='bepasty',
                                short_description=_('File & Snippet Sharing'),
                                description=_description, manual_page='bepasty',
@@ -79,6 +78,9 @@ class BepastyApp(app_module.App):
                                       clients=manifest.clients)
         self.add(shortcut)
 
+        packages = Packages('packages-bepasty', ['bepasty'])
+        self.add(packages)
+
         firewall = Firewall('firewall-bepasty', info.name,
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
@@ -97,7 +99,7 @@ class BepastyApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', actions.superuser_run, 'bepasty',
                 ['setup', '--domain-name', 'freedombox.local'])
     helper.call('post', app.enable)
