@@ -6,7 +6,7 @@ Django form for configuring calibre.
 from django import forms
 from django.core import validators
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth.modules import calibre
 
