@@ -7,27 +7,23 @@ import os
 import socket
 
 import augeas
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
-from plinth.modules.apache import (user_of_uws_url, uws_url_of_user,
-                                   get_users_with_website)
+from plinth.daemon import RelatedDaemon
+from plinth.modules.apache import (get_users_with_website, user_of_uws_url,
+                                   uws_url_of_user)
 from plinth.modules.names.components import DomainType
+from plinth.package import Packages
 from plinth.signals import domain_added
 
-version = 2
-
-is_essential = True
-
 _description = [
     _('Here you can set some general configuration options '
       'like hostname, domain name, webserver home page etc.')
 ]
 
-depends = ['apache', 'firewall', 'names']
-
 APACHE_CONF_ENABLED_DIR = '/etc/apache2/conf-enabled'
 APACHE_HOMEPAGE_CONF_FILE_NAME = 'freedombox-apache-homepage.conf'
 APACHE_HOMEPAGE_CONFIG = os.path.join(APACHE_CONF_ENABLED_DIR,
@@ -44,15 +40,18 @@ class ConfigApp(app_module.App):
 
     app_id = 'config'
 
+    _version = 3
+
     can_be_disabled = False
 
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               is_essential=is_essential, depends=depends,
-                               name=_('General Configuration'), icon='fa-cog',
-                               description=_description,
+        info = app_module.Info(app_id=self.app_id, version=self._version,
+                               is_essential=True,
+                               depends=['apache', 'firewall', 'names'
+                                        ], name=_('General Configuration'),
+                               icon='fa-cog', description=_description,
                                manual_page='Configure')
         self.add(info)
 
@@ -60,10 +59,22 @@ class ConfigApp(app_module.App):
                               'config:index', parent_url_name='system')
         self.add(menu_item)
 
+        packages = Packages('packages-config', ['zram-tools'])
+        self.add(packages)
+
+        daemon1 = RelatedDaemon('related-daemon-config1', 'systemd-journald')
+        self.add(daemon1)
+
+        daemon2 = RelatedDaemon('related-daemon-config2', 'rsyslog')
+        self.add(daemon2)
+
         domain_type = DomainType('domain-type-static', _('Domain Name'),
                                  'config:index', can_have_certificate=True)
         self.add(domain_type)
 
+    @staticmethod
+    def post_init():
+        """Perform post initialization operations."""
         # Register domain with Name Services module.
         domainname = get_domainname()
         if domainname:
@@ -161,7 +172,7 @@ def change_home_page(shortcut_id):
     """
     url = _home_page_scid2url(shortcut_id)
     if url is None:
-        url = '/plinth/'  	# fall back to default url if scid is unknown.
+        url = '/plinth/'  # fall back to default url if scid is unknown.
 
     # URL may be a reverse_lazy() proxy
     actions.superuser_run('config', ['set-home-page', str(url)])
@@ -181,8 +192,19 @@ def set_advanced_mode(advanced_mode):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
+    app.setup(old_version)
     _migrate_home_page_config()
 
+    # systemd-journald is socket activated, it may not be running and it does
+    # not support reload.
+    actions.superuser_run('service', ['try-restart', 'systemd-journald'])
+    # rsyslog when enabled, is activated by syslog.socket (shipped by systemd).
+    # See: https://www.freedesktop.org/wiki/Software/systemd/syslog/ .
+    actions.superuser_run('service', ['disable', 'rsyslog'])
+    # Ensure that rsyslog is not started by something else as it is installed
+    # by default on Debian systems.
+    actions.superuser_run('service', ['mask', 'rsyslog'])
+
 
 def _migrate_home_page_config():
     """Move the home page configuration to an external file."""
