@@ -4,7 +4,7 @@ Views for Coturn app.
 """
 
 from django.contrib import messages
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 import plinth.modules.coturn as coturn
 from plinth import views
