@@ -6,7 +6,7 @@ Django views for Deluge.
 import json
 
 from django.contrib import messages
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from plinth import actions, views
 
