@@ -4,14 +4,13 @@ FreedomBox app for system diagnostics.
 """
 
 import collections
-import importlib
 import logging
 import pathlib
 import threading
 
 import psutil
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ugettext_noop
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext_noop
 
 from plinth import app as app_module
 from plinth import cfg, daemon, glib, menu
@@ -20,10 +19,6 @@ from plinth.modules.backups.components import BackupRestore
 
 from . import manifest
 
-version = 1
-
-is_essential = True
-
 _description = [
     _('The system diagnostic test will run a number of checks on your '
       'system to confirm that applications and services are working as '
@@ -38,19 +33,22 @@ running_task = None
 
 current_results = {}
 
+results_lock = threading.Lock()
+
 
 class DiagnosticsApp(app_module.App):
     """FreedomBox app for diagnostics."""
 
     app_id = 'diagnostics'
 
+    _version = 1
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               is_essential=is_essential,
-                               name=_('Diagnostics'), icon='fa-heartbeat',
-                               description=_description,
+        info = app_module.Info(app_id=self.app_id, version=self._version,
+                               is_essential=True, name=_('Diagnostics'),
+                               icon='fa-heartbeat', description=_description,
                                manual_page='Diagnostics')
         self.add(info)
 
@@ -62,6 +60,9 @@ class DiagnosticsApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
+    @staticmethod
+    def post_init():
+        """Perform post initialization operations."""
         # Check periodically for low RAM space
         interval = 180 if cfg.develop else 3600
         glib.schedule(interval, _warn_about_low_ram_space)
@@ -90,37 +91,41 @@ def start_task():
 def run_on_all_enabled_modules():
     """Run diagnostics on all the enabled modules and store the result."""
     global current_results
-    current_results = {
-        'apps': [],
-        'results': collections.OrderedDict(),
-        'progress_percentage': 0
-    }
 
-    # Three result strings returned by tests, mark for translation and
+    # Four result strings returned by tests, mark for translation and
     # translate later.
-    ugettext_noop('passed')
-    ugettext_noop('failed')
-    ugettext_noop('error')
+    gettext_noop('passed')
+    gettext_noop('failed')
+    gettext_noop('error')
+    gettext_noop('warning')
 
     apps = []
-    for app in app_module.App.list():
-        # Don't run diagnostics on apps have not been setup yet.
-        # However, run on apps that need an upgrade.
-        module = importlib.import_module(app.__class__.__module__)
-        if module.setup_helper.get_state() == 'needs-setup':
-            continue
 
-        if not app.is_enabled():
-            continue
+    with results_lock:
+        current_results = {
+            'apps': [],
+            'results': collections.OrderedDict(),
+            'progress_percentage': 0
+        }
 
-        if not app.has_diagnostics():
-            continue
+        for app in app_module.App.list():
+            # Don't run diagnostics on apps have not been setup yet.
+            # However, run on apps that need an upgrade.
+            if app.needs_setup():
+                continue
 
-        apps.append((app.app_id, app))
-        app_name = app.info.name or app.app_id
-        current_results['results'][app.app_id] = {'name': app_name}
+            if not app.is_enabled():
+                continue
+
+            if not app.has_diagnostics():
+                continue
+
+            apps.append((app.app_id, app))
+            app_name = app.info.name or app.app_id
+            current_results['results'][app.app_id] = {'name': app_name}
+
+        current_results['apps'] = apps
 
-    current_results['apps'] = apps
     for current_index, (app_id, app) in enumerate(apps):
         app_results = {
             'diagnosis': None,
@@ -134,9 +139,10 @@ def run_on_all_enabled_modules():
                              exception)
             app_results['exception'] = str(exception)
 
-        current_results['results'][app_id].update(app_results)
-        current_results['progress_percentage'] = \
-            int((current_index + 1) * 100 / len(apps))
+        with results_lock:
+            current_results['results'][app_id].update(app_results)
+            current_results['progress_percentage'] = \
+                int((current_index + 1) * 100 / len(apps))
 
     global running_task
     running_task = None
@@ -193,23 +199,23 @@ def _warn_about_low_ram_space(request):
     if memory_info['free_bytes'] < 1024**3:
         # Translators: This is the unit of computer storage Mebibyte similar to
         # Megabyte.
-        memory_available_unit = ugettext_noop('MiB')
+        memory_available_unit = gettext_noop('MiB')
         memory_available = memory_info['free_bytes'] / 1024**2
     else:
         # Translators: This is the unit of computer storage Gibibyte similar to
         # Gigabyte.
-        memory_available_unit = ugettext_noop('GiB')
+        memory_available_unit = gettext_noop('GiB')
         memory_available = memory_info['free_bytes'] / 1024**3
 
     show = False
     if memory_info['percent_used'] > 90:
         severity = 'error'
-        advice_message = ugettext_noop(
+        advice_message = gettext_noop(
             'You should disable some apps to reduce memory usage.')
         show = True
     elif memory_info['percent_used'] > 75:
         severity = 'warning'
-        advice_message = ugettext_noop(
+        advice_message = gettext_noop(
             'You should not install any new apps on this system.')
         show = True
 
@@ -220,14 +226,14 @@ def _warn_about_low_ram_space(request):
             pass
         return
 
-    message = ugettext_noop(
+    message = gettext_noop(
         # xgettext:no-python-format
         'System is low on memory: {percent_used}% used, {memory_available} '
         '{memory_available_unit} free. {advice_message}')
-    title = ugettext_noop('Low Memory')
+    title = gettext_noop('Low Memory')
     data = {
         'app_icon': 'fa-heartbeat',
-        'app_name': 'translate:' + ugettext_noop('Diagnostics'),
+        'app_name': 'translate:' + gettext_noop('Diagnostics'),
         'percent_used': f'{memory_info["percent_used"]:.1f}',
         'memory_available': f'{memory_available:.1f}',
         'memory_available_unit': 'translate:' + memory_available_unit,
