@@ -4,7 +4,7 @@ FreedomBox app to configure ikiwiki.
 """
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -13,17 +13,11 @@ from plinth.modules.apache.components import Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
+from plinth.package import Packages
 from plinth.utils import format_lazy
 
 from . import manifest
 
-version = 1
-
-managed_packages = [
-    'ikiwiki', 'libdigest-sha-perl', 'libxml-writer-perl', 'xapian-omega',
-    'libsearch-xapian-perl', 'libimage-magick-perl'
-]
-
 _description = [
     _('ikiwiki is a simple wiki and blog application. It supports '
       'several lightweight markup languages, including Markdown, and '
@@ -45,11 +39,13 @@ class IkiwikiApp(app_module.App):
 
     app_id = 'ikiwiki'
 
+    _version = 1
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
 
-        info = app_module.Info(app_id=self.app_id, version=version,
+        info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('ikiwiki'), icon_filename='ikiwiki',
                                short_description=_('Wiki and Blog'),
                                description=_description, manual_page='Ikiwiki',
@@ -62,7 +58,11 @@ class IkiwikiApp(app_module.App):
                               'ikiwiki:index', parent_url_name='apps')
         self.add(menu_item)
 
-        self.refresh_sites()
+        packages = Packages('packages-ikiwiki', [
+            'ikiwiki', 'libdigest-sha-perl', 'libxml-writer-perl',
+            'xapian-omega', 'libsearch-xapian-perl', 'libimage-magick-perl'
+        ])
+        self.add(packages)
 
         firewall = Firewall('firewall-ikiwiki', info.name,
                             ports=['http', 'https'], is_external=True)
@@ -81,6 +81,10 @@ class IkiwikiApp(app_module.App):
                                        **manifest.backup)
         self.add(backup_restore)
 
+    def post_init(self):
+        """Perform post initialization operations."""
+        self.refresh_sites()
+
     def add_shortcut(self, site, title):
         """Add an ikiwiki shortcut to frontpage."""
         shortcut = frontpage.Shortcut('shortcut-ikiwiki-' + site, title,
@@ -109,6 +113,6 @@ class IkiwikiApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', actions.superuser_run, 'ikiwiki', ['setup'])
     helper.call('post', app.enable)
