@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 clients = [{
     'name': _('MediaWiki'),
@@ -15,7 +15,9 @@ backup = {
         'files': ['/etc/mediawiki/FreedomBoxSettings.php']
     },
     'data': {
-        'directories': ['/var/lib/mediawiki-db/']
+        'directories': [
+            '/var/lib/mediawiki-db/', '/var/lib/mediawiki/images/'
+        ]
     },
     'services': ['mediawiki-jobrunner']
 }
