@@ -5,7 +5,7 @@ FreedomBox app for Minetest server.
 
 import augeas
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
@@ -13,15 +13,12 @@ from plinth.daemon import Daemon
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
+from plinth.package import Packages
 from plinth.utils import format_lazy
 
 from . import manifest
 
-version = 2
-
-managed_services = ['minetest-server']
-
-mods = [
+_mods = [
     'minetest-mod-character-creator', 'minetest-mod-craftguide',
     'minetest-mod-infinite-chest', 'minetest-mod-lucky-block',
     'minetest-mod-maidroid', 'minetest-mod-mesecons',
@@ -32,8 +29,6 @@ mods = [
     'minetest-mod-unifieddyes', 'minetest-mod-worldedit'
 ]
 
-managed_packages = ['minetest-server'] + mods
-
 _description = [
     format_lazy(
         _('Minetest is a multiplayer infinite-world block sandbox. This '
@@ -54,11 +49,14 @@ class MinetestApp(app_module.App):
 
     app_id = 'minetest'
 
+    _version = 2
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
+
         info = app_module.Info(
-            app_id=self.app_id, version=version, name=_('Minetest'),
+            app_id=self.app_id, version=self._version, name=_('Minetest'),
             icon_filename='minetest', short_description=_('Block Sandbox'),
             description=_description, manual_page='Minetest',
             clients=manifest.clients,
@@ -78,11 +76,14 @@ class MinetestApp(app_module.App):
             login_required=False)
         self.add(shortcut)
 
+        packages = Packages('packages-minetest', ['minetest-server'] + _mods)
+        self.add(packages)
+
         firewall = Firewall('firewall-minetest', info.name,
                             ports=['minetest-plinth'], is_external=True)
         self.add(firewall)
 
-        daemon = Daemon('daemon-minetest', managed_services[0],
+        daemon = Daemon('daemon-minetest', 'minetest-server',
                         listen_ports=[(30000, 'udp4')])
         self.add(daemon)
 
@@ -98,7 +99,7 @@ class MinetestApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', app.enable)
 
 
