@@ -3,10 +3,10 @@
 URLs for the name services module
 """
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from . import views
 
 urlpatterns = [
-    url(r'^sys/names/$', views.index, name='index'),
+    re_path(r'^sys/names/$', views.index, name='index'),
 ]
