@@ -3,17 +3,14 @@
 FreedomBox app for power controls.
 """
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import app as app_module
+from plinth import menu
 from plinth.modules.backups.components import BackupRestore
 
 from . import manifest
 
-version = 1
-
-is_essential = True
-
 _description = [_('Restart or shut down the system.')]
 
 app = None
@@ -24,17 +21,22 @@ class PowerApp(app_module.App):
 
     app_id = 'power'
 
+    _version = 1
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
 
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               is_essential=is_essential, name=_('Power'),
-                               description=_description, manual_page='Power')
+        info = app_module.Info(app_id=self.app_id, version=self._version,
+                               is_essential=True, name=_('Power'),
+                               icon='fa-power-off', description=_description,
+                               manual_page='Power')
         self.add(info)
 
+        menu_item = menu.Menu('menu-power', info.name, None, info.icon,
+                              'power:index', parent_url_name='system')
+        self.add(menu_item)
+
         backup_restore = BackupRestore('backup-restore-power',
                                        **manifest.backup)
         self.add(backup_restore)
-
-        # not in menu, see issue #834
