@@ -6,7 +6,7 @@ FreedomBox app for Quassel.
 import pathlib
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -17,18 +17,11 @@ from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.letsencrypt.components import LetsEncrypt
 from plinth.modules.users.components import UsersAndGroups
+from plinth.package import Packages
 from plinth.utils import format_lazy
 
 from . import manifest
 
-version = 1
-
-managed_services = ['quasselcore']
-
-managed_packages = ['quassel-core']
-
-managed_paths = [pathlib.Path('/var/lib/quassel/')]
-
 _description = [
     format_lazy(
         _('Quassel is an IRC application that is split into two parts, a '
@@ -53,10 +46,13 @@ class QuasselApp(app_module.App):
 
     app_id = 'quassel'
 
+    _version = 1
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
+
+        info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('Quassel'), icon_filename='quassel',
                                short_description=_('IRC Client'),
                                description=_description, manual_page='Quassel',
@@ -76,20 +72,23 @@ class QuasselApp(app_module.App):
             login_required=True)
         self.add(shortcut)
 
+        packages = Packages('packages-quassel', ['quassel-core'])
+        self.add(packages)
+
         firewall = Firewall('firewall-quassel', info.name,
                             ports=['quassel-plinth'], is_external=True)
         self.add(firewall)
 
         letsencrypt = LetsEncrypt(
             'letsencrypt-quassel', domains=get_domains,
-            daemons=managed_services, should_copy_certificates=True,
+            daemons=['quasselcore'], should_copy_certificates=True,
             private_key_path='/var/lib/quassel/quasselCert.pem',
             certificate_path='/var/lib/quassel/quasselCert.pem',
             user_owner='quasselcore', group_owner='quassel',
             managing_app='quassel')
         self.add(letsencrypt)
 
-        daemon = Daemon('daemon-quassel', managed_services[0],
+        daemon = Daemon('daemon-quassel', 'quasselcore',
                         listen_ports=[(4242, 'tcp4'), (4242, 'tcp6')])
         self.add(daemon)
 
@@ -104,17 +103,11 @@ class QuasselApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', app.enable)
     app.get_component('letsencrypt-quassel').setup_certificates()
 
 
-def get_available_domains():
-    """Return an iterator with all domains able to have a certificate."""
-    return (domain.name for domain in names.components.DomainName.list()
-            if domain.domain_type.can_have_certificate)
-
-
 def set_domain(domain):
     """Set the TLS domain by writing a file to data directory."""
     if domain:
@@ -131,7 +124,7 @@ def get_domain():
         pass
 
     if not domain:
-        domain = next(get_available_domains(), None)
+        domain = next(names.get_available_tls_domains(), None)
         set_domain(domain)
 
     return domain
