@@ -6,7 +6,7 @@ FreedomBox app for radicale.
 import logging
 
 import augeas
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -15,14 +15,11 @@ from plinth.modules.apache.components import Uwsgi, Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
+from plinth.package import Packages
 from plinth.utils import Version, format_lazy
 
 from . import manifest
 
-version = 2
-
-managed_packages = ['radicale']
-
 _description = [
     format_lazy(
         _('Radicale is a CalDAV and CardDAV server. It allows synchronization '
@@ -48,10 +45,13 @@ class RadicaleApp(app_module.App):
 
     app_id = 'radicale'
 
+    _version = 2
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
+
+        info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('Radicale'), icon_filename='radicale',
                                short_description=_('Calendar and Addressbook'),
                                description=_description,
@@ -71,6 +71,9 @@ class RadicaleApp(app_module.App):
                                       login_required=True)
         self.add(shortcut)
 
+        packages = Packages('packages-radicale', ['radicale'])
+        self.add(packages)
+
         firewall = Firewall('firewall-radicale', info.name,
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
@@ -98,7 +101,7 @@ class RadicaleApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', app.enable)
 
 
