@@ -5,7 +5,7 @@ FreedomBox app to configure Searx.
 
 import os
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -14,13 +14,10 @@ from plinth.modules.apache.components import Uwsgi, Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
+from plinth.package import Packages
 
 from . import manifest
 
-version = 4
-
-managed_packages = ['searx']
-
 _description = [
     _('Searx is a privacy-respecting Internet metasearch engine. '
       'It aggregrates and displays results from multiple search engines.'),
@@ -28,8 +25,6 @@ _description = [
       'It stores no cookies by default.')
 ]
 
-manual_page = 'Searx'
-
 app = None
 
 
@@ -38,6 +33,8 @@ class SearxApp(app_module.App):
 
     app_id = 'searx'
 
+    _version = 4
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
@@ -45,7 +42,7 @@ class SearxApp(app_module.App):
         groups = {'web-search': _('Search the web')}
 
         info = app_module.Info(
-            app_id=self.app_id, version=version, name=_('Searx'),
+            app_id=self.app_id, version=self._version, name=_('Searx'),
             icon_filename='searx', short_description=_('Web Search'),
             description=_description, manual_page='Searx',
             clients=manifest.clients,
@@ -65,6 +62,9 @@ class SearxApp(app_module.App):
             allowed_groups=list(groups))
         self.add(shortcut)
 
+        packages = Packages('packages-searx', ['searx'])
+        self.add(packages)
+
         firewall = Firewall('firewall-searx', info.name,
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
@@ -110,7 +110,7 @@ class SearxWebserverAuth(Webserver):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', actions.superuser_run, 'searx', ['setup'])
     if not old_version or old_version < 3:
         helper.call('post', actions.superuser_run, 'searx',
