@@ -4,7 +4,7 @@ Django form for configuring Searx.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class SearxForm(forms.Form):
