@@ -7,24 +7,17 @@ import re
 import subprocess
 from collections import defaultdict
 
-import requests
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
-from plinth import menu, module_loader
+from plinth import menu
+from plinth.daemon import Daemon, RelatedDaemon
 from plinth.modules.backups.components import BackupRestore
+from plinth.package import Packages
 
 from . import manifest
 
-version = 6
-
-is_essential = True
-
-managed_packages = ['fail2ban', 'debsecan']
-
-managed_services = ['fail2ban']
-
 ACCESS_CONF_FILE = '/etc/security/access.d/50freedombox.conf'
 ACCESS_CONF_FILE_OLD = '/etc/security/access.conf'
 ACCESS_CONF_SNIPPET = '-:ALL EXCEPT root fbx plinth (admin) (sudo):ALL'
@@ -39,11 +32,14 @@ class SecurityApp(app_module.App):
 
     app_id = 'security'
 
+    _version = 7
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               is_essential=is_essential, name=_('Security'),
+
+        info = app_module.Info(app_id=self.app_id, version=self._version,
+                               is_essential=True, name=_('Security'),
                                icon='fa-lock', manual_page='Security')
         self.add(info)
 
@@ -51,6 +47,12 @@ class SecurityApp(app_module.App):
                               'security:index', parent_url_name='system')
         self.add(menu_item)
 
+        packages = Packages('packages-security', ['fail2ban', 'debsecan'])
+        self.add(packages)
+
+        daemon = RelatedDaemon('related-daemon-fail2ban', 'fail2ban')
+        self.add(daemon)
+
         backup_restore = BackupRestore('backup-restore-security',
                                        **manifest.backup)
         self.add(backup_restore)
@@ -58,8 +60,11 @@ class SecurityApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install the required packages"""
-    helper.install(managed_packages)
-    setup_fail2ban()
+    app.setup(old_version)
+    if not old_version:
+        enable_fail2ban()
+
+    actions.superuser_run('service', ['reload', 'fail2ban'])
 
     # Migrate to new config file.
     enabled = get_restricted_access_enabled()
@@ -68,10 +73,9 @@ def setup(helper, old_version=None):
         set_restricted_access(True)
 
 
-def setup_fail2ban():
+def enable_fail2ban():
     actions.superuser_run('service', ['unmask', 'fail2ban'])
     actions.superuser_run('service', ['enable', 'fail2ban'])
-    actions.superuser_run('service', ['reload', 'fail2ban'])
 
 
 def get_restricted_access_enabled():
@@ -107,12 +111,6 @@ def get_apps_report():
             (label, package, *_) = line.split()
             cves[label].add(package)
 
-    try:
-        past_cves = requests.get(
-            'https://security-tracker.debian.org/tracker/data/json').json()
-    except Exception:
-        past_cves = None
-
     service_exposure_lines = subprocess.check_output(
         ['systemd-analyze', 'security']).decode().strip().split('\n')
     service_exposure_lines.pop(0)
@@ -128,45 +126,44 @@ def get_apps_report():
             'name': 'freedombox',
             'packages': {'freedombox'},
             'vulns': 0,
-            'past_vulns': 0 if past_cves else None,
         }
     }
-    if past_cves and 'freedombox' in past_cves:
-        apps['freedombox']['past_vulns'] = len(past_cves['freedombox'])
+    for app_ in app_module.App.list():
+        components = app_.get_components_of_type(Packages)
+        packages = []
+        for component in components:
+            packages += component.packages
 
-    for module_name, module in module_loader.loaded_modules.items():
-        try:
-            packages = module.managed_packages
-        except AttributeError:
+        if not packages:
             continue  # app has no managed packages
 
-        try:
-            services = module.managed_services
-        except AttributeError:
-            services = None
+        components = app_.get_components_of_type(Daemon)
+        services = []
+        for component in components:
+            services.append(component.unit)
 
         # filter out apps not setup yet
-        if module.setup_helper.get_state() == 'needs-setup':
+        if app_.needs_setup():
             continue
 
-        apps[module_name] = {
-            'name': module_name,
+        apps[app_.app_id] = {
+            'name': app_.app_id,
             'packages': set(packages),
             'vulns': 0,
-            'past_vulns': 0 if past_cves else None,
             'sandboxed': None,
         }
 
-        for package in packages:
-            if past_cves and package in past_cves:
-                apps[module_name]['past_vulns'] += len(past_cves[package])
-
         if services:
-            apps[module_name]['sandboxed'] = False
+            apps[app_.app_id]['sandboxed'] = False
             for service in services:
+                # If an app lists a timer, work on the associated service
+                # instead
+                if service.rpartition('.')[-1] == 'timer':
+                    service = service.rpartition('.')[0]
+
                 if _get_service_is_sandboxed(service):
-                    apps[module_name]['sandboxed'] = True
-                    apps[module_name][
+                    apps[app_.app_id]['sandboxed'] = True
+                    apps[app_.app_id][
                         'sandbox_coverage'] = sandbox_coverage.get(service)
 
     for cve_packages in cves.values():
@@ -192,18 +189,18 @@ def _get_service_is_sandboxed(service):
         '--property=PrivateMounts',
     ]).decode().strip().split('\n')
     pairs = [line.partition('=')[::2] for line in lines]
-    properties = {name: value for name, value in pairs}
-    if properties['ProtectSystem'] in ['yes', 'full', 'strict']:
+    properties = dict(pairs)
+    if properties.get('ProtectSystem') in ['yes', 'full', 'strict']:
         return True
 
-    if properties['ProtectHome'] in ['yes', 'read-only', 'tmpfs']:
+    if properties.get('ProtectHome') in ['yes', 'read-only', 'tmpfs']:
         return True
 
     for name in [
             'PrivateTmp', 'PrivateDevices', 'PrivateNetwork', 'PrivateUsers',
             'PrivateMounts'
     ]:
-        if properties[name] == 'yes':
+        if properties.get(name) == 'yes':
             return True
 
     return False
