@@ -4,7 +4,7 @@ FreedomBox app to configure Shadowsocks.
 """
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -12,16 +12,11 @@ from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
+from plinth.package import Packages
 from plinth.utils import format_lazy
 
 from . import manifest
 
-version = 3
-
-managed_services = ['shadowsocks-libev-local@freedombox']
-
-managed_packages = ['shadowsocks-libev']
-
 _description = [
     _('Shadowsocks is a lightweight and secure SOCKS5 proxy, designed to '
       'protect your Internet traffic. It can be used to bypass Internet '
@@ -44,10 +39,15 @@ class ShadowsocksApp(app_module.App):
 
     app_id = 'shadowsocks'
 
+    _version = 3
+
+    DAEMON = 'shadowsocks-libev-local@freedombox'
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
+
+        info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('Shadowsocks'),
                                icon_filename='shadowsocks',
                                short_description=_('Socks5 Proxy'),
@@ -68,12 +68,15 @@ class ShadowsocksApp(app_module.App):
             login_required=True)
         self.add(shortcut)
 
+        packages = Packages('packages-shadowsocks', ['shadowsocks-libev'])
+        self.add(packages)
+
         firewall = Firewall('firewall-shadowsocks', info.name,
                             ports=['shadowsocks-local-plinth'],
                             is_external=False)
         self.add(firewall)
 
-        daemon = Daemon('daemon-shadowsocks', managed_services[0],
+        daemon = Daemon('daemon-shadowsocks', self.DAEMON,
                         listen_ports=[(1080, 'tcp4'), (1080, 'tcp6')])
         self.add(daemon)
 
@@ -84,6 +87,6 @@ class ShadowsocksApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', actions.superuser_run, 'shadowsocks', ['setup'])
     helper.call('post', app.enable)
