@@ -4,7 +4,7 @@ FreedomBox configuration form for OpenSSH server.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class SSHServerForm(forms.Form):
