@@ -3,7 +3,7 @@
 FreedomBox app for configuring Transmission.
 """
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth.modules.storage.forms import (DirectorySelectForm,
                                           DirectoryValidator)
