@@ -4,7 +4,7 @@ FreedomBox app to configure Tiny Tiny RSS.
 """
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -14,18 +14,11 @@ from plinth.modules.apache.components import Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
+from plinth.package import Packages
 from plinth.utils import Version, format_lazy
 
 from . import manifest
 
-version = 3
-
-managed_services = ['tt-rss']
-
-managed_packages = [
-    'tt-rss', 'postgresql', 'dbconfig-pgsql', 'php-pgsql', 'python3-psycopg2'
-]
-
 _description = [
     _('Tiny Tiny RSS is a news feed (RSS/Atom) reader and aggregator, '
       'designed to allow reading news from any location, while feeling as '
@@ -47,13 +40,15 @@ class TTRSSApp(app_module.App):
 
     app_id = 'ttrss'
 
+    _version = 3
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
 
         groups = {'feed-reader': _('Read and subscribe to news feeds')}
 
-        info = app_module.Info(app_id=self.app_id, version=version,
+        info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('Tiny Tiny RSS'), icon_filename='ttrss',
                                short_description=_('News Feed Reader'),
                                description=_description,
@@ -74,6 +69,12 @@ class TTRSSApp(app_module.App):
                                       allowed_groups=list(groups))
         self.add(shortcut)
 
+        packages = Packages('packages-ttrss', [
+            'tt-rss', 'postgresql', 'dbconfig-pgsql', 'php-pgsql',
+            'python3-psycopg2'
+        ])
+        self.add(packages)
+
         firewall = Firewall('firewall-ttrss', info.name,
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
@@ -82,7 +83,7 @@ class TTRSSApp(app_module.App):
                               urls=['https://{host}/tt-rss'])
         self.add(webserver)
 
-        daemon = Daemon('daemon-ttrss', managed_services[0])
+        daemon = Daemon('daemon-ttrss', 'tt-rss')
         self.add(daemon)
 
         users_and_groups = UsersAndGroups('users-and-groups-ttrss',
@@ -98,23 +99,32 @@ class TTRSSApp(app_module.App):
         super().enable()
         actions.superuser_run('ttrss', ['enable-api-access'])
 
+        # Try to set the domain to one of the available TLS domains
+        domain = get_domain()
+        if not domain or domain == 'localhost':
+            from plinth.modules import names
+            domain = next(names.get_available_tls_domains(), None)
+            set_domain(domain)
+
 
 class TTRSSBackupRestore(BackupRestore):
     """Component to backup/restore TT-RSS"""
 
     def backup_pre(self, packet):
         """Save database contents."""
+        super().backup_pre(packet)
         actions.superuser_run('ttrss', ['dump-database'])
 
     def restore_post(self, packet):
         """Restore database contents."""
+        super().restore_post(packet)
         actions.superuser_run('ttrss', ['restore-database'])
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.call('pre', actions.superuser_run, 'ttrss', ['pre-setup'])
-    helper.install(managed_packages)
+    app.setup(old_version)
     helper.call('post', actions.superuser_run, 'ttrss', ['setup'])
     helper.call('post', app.enable)
 
@@ -124,11 +134,22 @@ def force_upgrade(helper, packages):
     if 'tt-rss' not in packages:
         return False
 
-    # Allow tt-rss any lower version to upgrade to 19.8.*
+    # Allow tt-rss any lower version to upgrade to 21.*
     package = packages['tt-rss']
-    if Version(package['new_version']) > Version('19.9~'):
+    if Version(package['new_version']) > Version('22~'):
         return False
 
     helper.install(['tt-rss'], force_configuration='new')
     actions.superuser_run('ttrss', ['setup'])
     return True
+
+
+def get_domain():
+    """Read TLS domain from tt-rss config file."""
+    return actions.superuser_run('ttrss', ['get-domain']).strip()
+
+
+def set_domain(domain):
+    """Set the TLS domain in tt-rss configuration file."""
+    if domain:
+        actions.superuser_run('ttrss', ['set-domain', domain])
