@@ -9,25 +9,19 @@ import os
 import subprocess
 
 from aptsources import sourceslist
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ugettext_noop
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext_noop
 
 import plinth
 from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, glib, kvstore, menu
+from plinth.daemon import RelatedDaemon
 from plinth.modules.backups.components import BackupRestore
+from plinth.package import Packages
 
 from . import manifest
 
-version = 9
-
-is_essential = True
-
-managed_packages = ['unattended-upgrades', 'needrestart']
-
-managed_services = ['freedombox-dist-upgrade']
-
 first_boot_steps = [
     {
         'id': 'backports_wizard',
@@ -68,13 +62,16 @@ class UpgradesApp(app_module.App):
 
     app_id = 'upgrades'
 
+    _version = 10
+
     can_be_disabled = False
 
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               is_essential=is_essential, name=_('Update'),
+
+        info = app_module.Info(app_id=self.app_id, version=self._version,
+                               is_essential=True, name=_('Software Update'),
                                icon='fa-refresh', description=_description,
                                manual_page='Upgrades')
         self.add(info)
@@ -83,10 +80,20 @@ class UpgradesApp(app_module.App):
                               'upgrades:index', parent_url_name='system')
         self.add(menu_item)
 
+        packages = Packages('packages-upgrades',
+                            ['unattended-upgrades', 'needrestart'])
+        self.add(packages)
+
+        daemon = RelatedDaemon('related-daemon-upgrades',
+                               'freedombox-dist-upgrade')
+        self.add(daemon)
+
         backup_restore = BackupRestore('backup-restore-upgrades',
                                        **manifest.backup)
         self.add(backup_restore)
 
+    def post_init(self):
+        """Perform post initialization operations."""
         self._show_new_release_notification()
 
         # Check every day (every 3 minutes in debug mode):
@@ -119,10 +126,10 @@ class UpgradesApp(app_module.App):
 
         data = {
             'version': plinth.__version__,
-            'app_name': 'translate:' + ugettext_noop('Updates'),
+            'app_name': 'translate:' + gettext_noop('Software Update'),
             'app_icon': 'fa-refresh'
         }
-        title = ugettext_noop('FreedomBox Updated')
+        title = gettext_noop('FreedomBox Updated')
         note = Notification.update_or_create(
             id='upgrades-new-release', app_id='upgrades', severity='info',
             title=title, body_template='upgrades-new-release.html', data=data,
@@ -132,7 +139,7 @@ class UpgradesApp(app_module.App):
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
+    app.setup(old_version)
 
     # Enable automatic upgrades but only on first install
     if not old_version and not cfg.develop:
@@ -207,8 +214,8 @@ def check_dist_upgrade(_):
             logger.info('Skip dist upgrade: --test is not set.')
         elif 'not-enough-free-space' in reason:
             logger.warning('Skip dist upgrade: Not enough free space in /.')
-            title = ugettext_noop('Could not start distribution update')
-            message = ugettext_noop(
+            title = gettext_noop('Could not start distribution update')
+            message = gettext_noop(
                 'There is not enough free space in the root partition to '
                 'start the distribution update. Please ensure at least 5 GB '
                 'is free. Distribution update will be retried after 24 hours,'
@@ -220,8 +227,8 @@ def check_dist_upgrade(_):
                 }], group='admin')
         elif 'started-dist-upgrade' in reason:
             logger.info('Started dist upgrade.')
-            title = ugettext_noop('Distribution update started')
-            message = ugettext_noop(
+            title = gettext_noop('Distribution update started')
+            message = gettext_noop(
                 'Started update to next stable release. This may take a long '
                 'time to complete.')
             Notification.update_or_create(id='upgrades-dist-upgrade-started',
