@@ -11,15 +11,14 @@ from django.contrib.auth.models import Group, User
 from django.core import validators
 from django.core.exceptions import ValidationError
 from django.utils.deconstruct import deconstructible
-from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy
+from django.utils.translation import gettext as _
+from django.utils.translation import gettext_lazy
 
 import plinth.forms
 from plinth import actions
 from plinth.errors import ActionError
 from plinth.modules import first_boot
 from plinth.modules.security import set_restricted_access
-from plinth.translation import set_language
 from plinth.utils import is_user_admin
 
 from . import get_last_admin_user
@@ -61,23 +60,29 @@ class UsernameValidator(validators.RegexValidator):
 
     """
     regex = r'^[\w.@][\w.@-]+\Z'
-    message = ugettext_lazy('Enter a valid username.')
+    message = gettext_lazy('Enter a valid username.')
     flags = re.ASCII
 
 
 USERNAME_FIELD = forms.CharField(
-    label=ugettext_lazy('Username'), max_length=150,
+    label=gettext_lazy('Username'), max_length=150,
     validators=[UsernameValidator()],
-    help_text=ugettext_lazy('Required. 150 characters or fewer. English '
-                            'letters, digits and @/./-/_ only.'))
+    help_text=gettext_lazy('Required. 150 characters or fewer. English '
+                           'letters, digits and @/./-/_ only.'))
 
 
 class PasswordConfirmForm(forms.Form):
     """Password confirmation form."""
     confirm_password = forms.CharField(
         widget=forms.PasswordInput,
-        label=ugettext_lazy('Authorization Password'), help_text=ugettext_lazy(
-            'Enter your current password to authorize account modifications.'))
+        label=gettext_lazy('Authorization Password'))
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        self.fields['confirm_password'].help_text = _(
+            'Enter the password for user "{user}" to authorize account '
+            'modifications.').format(user=self.request.user.username)
 
     def clean_confirm_password(self):
         """Check that current user's password matches."""
@@ -100,8 +105,8 @@ class CreateUserForm(ValidNewUsernameCheckMixin,
     username = USERNAME_FIELD
     groups = forms.MultipleChoiceField(
         choices=UsersAndGroups.get_group_choices,
-        label=ugettext_lazy('Permissions'), required=False,
-        widget=plinth.forms.CheckboxSelectMultiple, help_text=ugettext_lazy(
+        label=gettext_lazy('Permissions'), required=False,
+        widget=plinth.forms.CheckboxSelectMultiple, help_text=gettext_lazy(
             'Select which services should be available to the new '
             'user. The user will be able to log in to services that '
             'support single sign-on through LDAP, if they are in the '
@@ -174,8 +179,8 @@ class UserUpdateForm(ValidNewUsernameCheckMixin, PasswordConfirmForm,
     """When user info is changed, also updates LDAP user."""
     username = USERNAME_FIELD
     ssh_keys = forms.CharField(
-        label=ugettext_lazy('Authorized SSH Keys'), required=False,
-        widget=forms.Textarea, help_text=ugettext_lazy(
+        label=gettext_lazy('Authorized SSH Keys'), required=False,
+        widget=forms.Textarea, help_text=gettext_lazy(
             'Setting an SSH public key will allow this user to '
             'securely log in to the system without using a '
             'password. You may enter multiple keys, one on each '
@@ -210,19 +215,21 @@ class UserUpdateForm(ValidNewUsernameCheckMixin, PasswordConfirmForm,
         })
 
         choices = []
+        django_groups = sorted(self.fields['groups'].choices,
+                               key=lambda choice: choice[1])
+        for group_id, group_name in django_groups:
+            try:
+                group_id = group_id.value
+            except AttributeError:
+                pass
 
-        for c in sorted(self.fields['groups'].choices, key=lambda x: x[1]):
-            # Handle case where groups exist in database for
-            # applications not installed yet.
-            if c[1] in group_choices:
-                # Replace group names with descriptions
-                if c[1] == 'admin' and self.is_last_admin_user:
-                    choices.append((c[0], {
-                        'label': group_choices[c[1]],
-                        'readonly': True
-                    }))
-                else:
-                    choices.append((c[0], group_choices[c[1]]))
+            # Show choices only from groups declared by apps.
+            if group_name in group_choices:
+                label = group_choices[group_name]
+                if group_name == 'admin' and self.is_last_admin_user:
+                    label = {'label': label, 'disabled': True}
+
+                choices.append((group_id, label))
 
         self.fields['groups'].label = _('Permissions')
         self.fields['groups'].choices = choices
@@ -242,10 +249,6 @@ class UserUpdateForm(ValidNewUsernameCheckMixin, PasswordConfirmForm,
         auth_username = self.request.user.username
         confirm_password = self.cleaned_data['confirm_password']
 
-        # If user is updating their own profile then only translate the pages
-        if self.username == auth_username:
-            set_language(self.request, None, user.userprofile.language)
-
         if commit:
             user.save()
             self.save_m2m()
@@ -323,18 +326,20 @@ class UserUpdateForm(ValidNewUsernameCheckMixin, PasswordConfirmForm,
 
         return user
 
-    def validate_last_admin_user(self, groups):
-        group_names = [group.name for group in groups]
-        if 'admin' not in group_names:
-            raise ValidationError(
-                _('Cannot delete the only administrator in the system.'))
+    def clean_groups(self):
+        """Validate groups to ensure admin group for last admin.
 
-    def clean(self):
-        """Override clean to add form validation logic."""
-        cleaned_data = super().clean()
+        For the last admin user, we disable the checkbox for 'admin' group so
+        that it can't be unchecked. However, this means that browser will no
+        longer submit that value. Forcefully add 'admin' group in this case.
+
+        """
+        groups = self.cleaned_data['groups']
         if self.is_last_admin_user:
-            self.validate_last_admin_user(cleaned_data.get("groups"))
-        return cleaned_data
+            groups = groups | self.fields['groups'].queryset.filter(
+                **{'name': 'admin'})
+
+        return groups
 
 
 class UserChangePasswordForm(PasswordConfirmForm, SetPasswordForm):
