@@ -10,7 +10,7 @@ import struct
 import time
 import uuid
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth.utils import import_from_gi
 
