@@ -7,8 +7,10 @@ import configparser
 import logging
 import os
 import pathlib
+import subprocess
 import tempfile
 import time
+import warnings
 from contextlib import contextmanager
 
 import pytest
@@ -48,9 +50,9 @@ _site_url = {
 
 _sys_modules = [
     'avahi', 'backups', 'bind', 'cockpit', 'config', 'datetime', 'diagnostics',
-    'dynamicdns', 'firewall', 'letsencrypt', 'monkeysphere', 'names',
-    'networks', 'pagekite', 'performance', 'power', 'security', 'snapshot',
-    'ssh', 'storage', 'upgrades', 'users'
+    'dynamicdns', 'firewall', 'letsencrypt', 'names', 'networks', 'pagekite',
+    'performance', 'power', 'security', 'snapshot', 'ssh', 'storage',
+    'upgrades', 'users'
 ]
 
 
@@ -247,13 +249,13 @@ def _create_admin_account(browser, username, password):
 
 
 def login(browser):
-    """Login to the interface."""
+    """Login to the FreedomBox interface with default test account."""
     login_with_account(browser, base_url, config['DEFAULT']['username'],
                        config['DEFAULT']['password'])
 
 
 def login_with_account(browser, url, username, password=None):
-
+    """Login to the FreedomBox interface with provided account."""
     if password is None:
         password = get_password(username)
     # XXX: Find a way to remove the hardcoded jsxc URL
@@ -268,7 +270,7 @@ def login_with_account(browser, url, username, password=None):
 
         visit(browser, '/plinth/accounts/logout/')
 
-    login_button = browser.find_link_by_href('/plinth/accounts/login/')
+    login_button = browser.links.find_by_href('/plinth/accounts/login/')
     if login_button:
         login_button.first.click()
         if login_button:
@@ -293,6 +295,11 @@ def login_with_account(browser, url, username, password=None):
             submit(browser, element=browser.find_by_name('next')[0])
 
 
+def logout(browser):
+    """Log out of the FreedomBox interface."""
+    visit(browser, '/plinth/accounts/logout/')
+
+
 #################
 # App utilities #
 #################
@@ -339,6 +346,8 @@ def install(browser, app_name):
                     browser.visit(browser.url)
                 else:
                     # This app is not available in this distribution
+                    warnings.warn(
+                        f'App {app_name} is not available in distribution')
                     pytest.skip('App not available in distribution')
             else:
                 install_button.click()
@@ -355,10 +364,9 @@ def _change_app_status(browser, app_name, change_status_to='enabled'):
 
     if button:
         should_enable_field = browser.find_by_id('id_should_enable')
-        if (should_enable_field.value == 'False'
-                and change_status_to == 'disabled') or (
-                    should_enable_field.value == 'True'
-                    and change_status_to == 'enabled'):
+        if (should_enable_field.value == 'False' and change_status_to
+                == 'disabled') or (should_enable_field.value == 'True'
+                                   and change_status_to == 'enabled'):
             submit(browser, element=button)
     else:
         checkbox_id = _app_checkbox_id[app_name]
@@ -399,7 +407,8 @@ def app_can_be_disabled(browser, app_name):
 def set_domain_name(browser, domain_name):
     nav_to_module(browser, 'config')
     browser.find_by_id('id_domainname').fill(domain_name)
-    submit(browser)
+    update_setup = browser.find_by_css('.btn-primary[type="submit"]')
+    submit(browser, element=update_setup)
 
 
 ########################
@@ -407,10 +416,15 @@ def set_domain_name(browser, domain_name):
 ########################
 def find_on_front_page(browser, app_name):
     browser.visit(base_url)
-    shortcuts = browser.find_link_by_href(f'/{app_name}/')
+    shortcuts = browser.links.find_by_href(f'/{app_name}/')
     return shortcuts
 
 
+def is_visible_on_front_page(browser, app_name):
+    shortcuts = find_on_front_page(browser, app_name)
+    return len(shortcuts) == 1
+
+
 ####################
 # Daemon utilities #
 ####################
@@ -424,6 +438,21 @@ def service_is_not_running(browser, app_name):
     return len(browser.find_by_id('service-not-running')) != 0
 
 
+def running_inside_container():
+    """Check if freedombox is running inside a container"""
+    # If the URL to connect to was overridden then assume that we are running
+    # tests on a different machine than the machine running freedombox. Assume
+    # running inside container to be conservative about tests.
+    if config['DEFAULT']['url'] != 'https://localhost':
+        return True
+
+    # If URL is not overridden then testing code and freedombox are running on
+    # the same machine. Proceed with a proper test.
+    result = subprocess.run(['systemd-detect-virt', '--container'],
+                            stdout=subprocess.PIPE, check=False)
+    return result.stdout.decode('utf-8').strip().lower() != 'none'
+
+
 ##############################
 # System -> Config utilities #
 ##############################
@@ -435,14 +464,15 @@ def set_advanced_mode(browser, mode):
     else:
         advanced_mode.uncheck()
 
-    submit(browser)
+    update_setup = browser.find_by_css('.btn-primary')
+    submit(browser, element=update_setup)
 
 
 ####################
 # Backup utilities #
 ####################
 def _click_button_and_confirm(browser, href):
-    buttons = browser.find_link_by_href(href)
+    buttons = browser.links.find_by_href(href)
     if buttons:
         submit(browser, buttons.first)
         submit(browser, expected_url='/plinth/sys/backups/')
@@ -459,7 +489,7 @@ def backup_create(browser, app_name, archive_name=None):
     if archive_name:
         _backup_delete_archive_by_name(browser, archive_name)
 
-    buttons = browser.find_link_by_href('/plinth/sys/backups/create/')
+    buttons = browser.links.find_by_href('/plinth/sys/backups/create/')
     submit(browser, buttons.first)
     eventually(browser.find_by_css, args=['.select-all'])
     browser.find_by_css('.select-all').first.uncheck()
@@ -490,7 +520,7 @@ def networks_set_firewall_zone(browser, zone):
     network_id = device['href'].split('/')[-3]
     device.click()
     edit_url = "/plinth/sys/networks/{}/edit/".format(network_id)
-    browser.find_link_by_href(edit_url).first.click()
+    browser.links.find_by_href(edit_url).first.click()
     browser.select('zone', zone)
     browser.find_by_tag("form").first.find_by_tag('input')[-1].click()
 
@@ -524,7 +554,7 @@ def create_user(browser, name, password=None, groups=[]):
         password = get_password(name)
 
     with wait_for_page_update(browser):
-        browser.find_link_by_href('/plinth/sys/users/create/').first.click()
+        browser.links.find_by_href('/plinth/sys/users/create/').first.click()
 
     browser.find_by_id('id_username').fill(name)
     browser.find_by_id('id_password1').fill(password)
@@ -542,7 +572,7 @@ def create_user(browser, name, password=None, groups=[]):
 def delete_user(browser, name):
     """Delete a user."""
     nav_to_module(browser, 'users')
-    delete_link = browser.find_link_by_href(
+    delete_link = browser.links.find_by_href(
         f'/plinth/sys/users/{name}/delete/')
 
     with wait_for_page_update(browser):
@@ -553,5 +583,80 @@ def delete_user(browser, name):
 def user_exists(browser, name):
     """Check if a user with a given name exists."""
     nav_to_module(browser, 'users')
-    links = browser.find_link_by_href(f'/plinth/sys/users/{name}/edit/')
+    links = browser.links.find_by_href(f'/plinth/sys/users/{name}/edit/')
     return len(links) == 1
+
+
+class BaseAppTests:
+    """Base class for common functional tests.
+
+    To run these tests on an app, the app should subclass this class with a
+    class name starting with 'Test'. This allows the app tests to be
+    automatically discovered while the base class tests to stay undiscovered.
+    Tests will apply to the app without the need not override each test.
+    """
+
+    app_name = ''
+    # TODO: Check the components of the app instead of configuring here.
+    has_service = False
+    has_web = True
+    check_diagnostics = True
+    diagnostics_delay = 0
+
+    def assert_app_running(self, session_browser):
+        """Assert that the app is running."""
+        if self.has_service:
+            assert service_is_running(session_browser, self.app_name)
+
+        if self.has_web:
+            assert is_available(session_browser, self.app_name)
+
+    def assert_app_not_running(self, session_browser):
+        """Assert that the app is not running."""
+        if self.has_service:
+            assert service_is_not_running(session_browser, self.app_name)
+
+        if self.has_web:
+            assert not is_available(session_browser, self.app_name)
+
+    @pytest.fixture(autouse=True)
+    def fixture_background(self, session_browser):
+        """Login, install, and enable the app."""
+        login(session_browser)
+        install(session_browser, self.app_name)
+        app_enable(session_browser, self.app_name)
+        yield
+        login(session_browser)
+        app_disable(session_browser, self.app_name)
+
+    def test_enable_disable(self, session_browser):
+        """Test enabling and disabling the app."""
+        app_disable(session_browser, self.app_name)
+        self.assert_app_not_running(session_browser)
+
+        app_enable(session_browser, self.app_name)
+        self.assert_app_running(session_browser)
+
+    def test_run_diagnostics(self, session_browser):
+        """Test that all app diagnostics are passing."""
+        if not self.check_diagnostics:
+            pytest.skip(f'Skipping diagnostics check for {self.app_name}.')
+
+        time.sleep(self.diagnostics_delay)
+        session_browser.find_by_id('id_extra_actions_button').click()
+        submit(session_browser, form_class='form-diagnostics-button')
+
+        warning_results = session_browser.find_by_css('.badge-warning')
+        if warning_results:
+            warnings.warn(
+                f'Diagnostics warnings for {self.app_name}: {warning_results}')
+
+        failure_results = session_browser.find_by_css('.badge-danger')
+        assert not failure_results
+
+    @pytest.mark.backups
+    def test_backup_restore(self, session_browser):
+        """Test that backup and restore operations work on the app."""
+        backup_create(session_browser, self.app_name, 'test_' + self.app_name)
+        backup_restore(session_browser, self.app_name, 'test_' + self.app_name)
+        self.assert_app_running(session_browser)
